@@ -11,7 +11,7 @@
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful, 
+# This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
@@ -28,8 +28,6 @@
 #-------------------------------------------------------------------------
 import os
 from io import StringIO
-from gramps.gen.const import GRAMPS_LOCALE as glocale
-_ = glocale.translation.gettext
 
 #-------------------------------------------------------------------------
 #
@@ -51,9 +49,11 @@ from gi.repository import GLib
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
+from gramps.gen.const import GRAMPS_LOCALE as glocale
+_ = glocale.translation.gettext
 from gramps.gen.utils.callback import Callback
 from .utils import process_pending_events
 from .views.navigationview import NavigationView
@@ -64,6 +64,7 @@ from gramps.gen.relationship import get_relationship_calculator
 from .glade import Glade
 from gramps.gen.utils.db import navigation_label
 from .widgets.progressdialog import ProgressMonitor, GtkProgressDialog
+from .dialog import ErrorDialog
 
 DISABLED = -1
 
@@ -73,13 +74,13 @@ DISABLED = -1
 #
 #-------------------------------------------------------------------------
 class History(Callback):
-    """ History manages the objects of a certain type that have been viewed, 
-        with ability to go back, or forward. 
+    """ History manages the objects of a certain type that have been viewed,
+        with ability to go back, or forward.
         When accessing an object, it should be pushed on the History.
     """
 
     __signals__ = {
-        'active-changed' : (str, ), 
+        'active-changed' : (str, ),
         'mru-changed' : (list, )
         }
 
@@ -100,7 +101,7 @@ class History(Callback):
         """
         for sig in self.signal_map:
             dbstate.connect(sig, self.signal_map[sig])
-            
+
     def clear(self):
         """
         Clears the history, resetting the values back to their defaults
@@ -110,7 +111,7 @@ class History(Callback):
         self.index = -1
         self.lock = False
 
-        if self.dbstate.open and self.nav_type == 'Person':
+        if self.dbstate.is_open() and self.nav_type == 'Person':
             initial_person = self.dbstate.db.find_initial_person()
             if initial_person:
                 self.push(initial_person.get_handle())
@@ -128,7 +129,7 @@ class History(Callback):
         for c in range(history_count):
             self.history.remove(del_id)
             self.index -= 1
-        
+
         mhc = self.mru.count(del_id)
         for c in range(mhc):
             self.mru.remove(del_id)
@@ -156,7 +157,7 @@ class History(Callback):
             if not isinstance(newact, str):
                 newact = str(newact)
             self.emit('active-changed', (newact,))
- 
+
     def forward(self, step=1):
         """
         Moves forward in the history list
@@ -191,7 +192,7 @@ class History(Callback):
             return newact
         except IndexError:
             return ""
-        
+
     def present(self):
         """
         return the person handle that is now active in the history
@@ -203,7 +204,7 @@ class History(Callback):
                 return ""
         except IndexError:
             return ""
-        
+
     def at_end(self):
         """
         returns True if we are at the end of the history list
@@ -230,7 +231,7 @@ class History(Callback):
         """
         for handle in handle_list:
             self.remove(handle)
-            
+
     def history_changed(self):
         """
         Called in response to an object-rebuild signal.
@@ -238,7 +239,7 @@ class History(Callback):
         """
         self.clear()
         self.emit('mru-changed', (self.mru, ))
-        
+
 #-------------------------------------------------------------------------
 #
 # Recent Docs Menu
@@ -249,9 +250,8 @@ _RCT_TOP = '<ui><menubar name="MenuBar"><menu action="FileMenu"><menu action="Op
 _RCT_BTM = '</menu></menu></menubar></ui>'
 
 from gramps.gen.recentfiles import RecentFiles
-import os
 
-class RecentDocsMenu(object):
+class RecentDocsMenu:
     def __init__(self, uistate, state, fileopen):
         self.action_group = Gtk.ActionGroup(name='RecentFiles')
         self.active = DISABLED
@@ -262,7 +262,11 @@ class RecentDocsMenu(object):
 
     def load(self, item):
         filename = item.get_path()
-        self.fileopen(filename)
+        try:
+            self.fileopen(filename)
+        except Exception as err:
+            ErrorDialog(_('Cannot load database'), str(err),
+                        parent=self.uistate.window)
 
     def build(self):
         buf = StringIO()
@@ -270,13 +274,13 @@ class RecentDocsMenu(object):
         gramps_rf = RecentFiles()
 
         count = 0
-        
+
         if self.active != DISABLED:
             self.uimanager.remove_ui(self.active)
             self.uimanager.remove_action_group(self.action_group)
             self.action_group = Gtk.ActionGroup(name='RecentFiles')
             self.active = DISABLED
-            
+
         actions = []
         rfiles = gramps_rf.gramps_recent_files
         rfiles.sort(key=lambda x: x.get_time(), reverse=True)
@@ -289,16 +293,16 @@ class RecentDocsMenu(object):
                 filename = os.path.basename(item.get_path())
                 action_id = "RecentMenu%d" % count
                 buf.write('<menuitem action="%s"/>' % action_id)
-                actions.append((action_id, None, title, None, None, 
+                actions.append((action_id, None, title, None, None,
                                 make_callback(item, self.load)))
                 mitem = Gtk.MenuItem(label=title, use_underline=False)
                 mitem.connect('activate', make_callback(item, self.load))
                 mitem.show()
                 new_menu.append(mitem)
             except RuntimeError:
+                # ignore no longer existing files
                 _LOG.info("Ignoring the RecentItem %s (%s)" % (title, filename))
-                pass    # ignore no longer existing files
-            
+
             count += 1
         buf.write(_RCT_BTM)
         self.action_group.add_actions(actions)
@@ -318,13 +322,14 @@ from .logger import RotateHandler
 
 class WarnHandler(RotateHandler):
 
-    def __init__(self, capacity, button):
+    def __init__(self, capacity, button, parent=None):
         RotateHandler.__init__(self, capacity)
         self.setLevel(logging.WARN)
         self.button = button
         button.on_clicked(self.display)
         self.timer = None
         self.last_line = '-1'
+        self.parent = parent
 
     def emit(self, record):
         if self.timer is None:
@@ -355,25 +360,29 @@ class WarnHandler(RotateHandler):
 
     def display(self, obj):
         obj.hide()
-        self.glade = Glade()
+        self.glade = Glade(toplevel='displaystate')
         top = self.glade.toplevel
         msg = self.glade.get_object('msg')
         buf = msg.get_buffer()
         for i in self.get_formatted_log():
             buf.insert_at_cursor(i + '\n')
+        if self.parent:
+            top.set_transient_for(self.parent)
         top.run()
         top.destroy()
 
 class DisplayState(Callback):
 
     __signals__ = {
-        'filters-changed' : (str, ), 
-        'filter-name-changed' : (str, str, str), 
-        'nameformat-changed' : None, 
-        'grampletbar-close-changed' : None, 
-        'update-available' : (list, ), 
+        'filters-changed' : (str, ),
+        'filter-name-changed' : (str, str, str),
+        'nameformat-changed' : None,
+        'placeformat-changed' : None,
+        'grampletbar-close-changed' : None,
+        'update-available' : (list, ),
+        'autobackup' : None,
         }
-    
+
     #nav_type to message
     NAV2MES = {
         'Person': _("No active person"),
@@ -387,7 +396,8 @@ class DisplayState(Callback):
         'Note': _("No active note"),
         }
 
-    BUSY_CURSOR = Gdk.Cursor.new(Gdk.CursorType.WATCH)
+    BUSY_CURSOR = Gdk.Cursor.new_for_display(Gdk.Display.get_default(),
+                                             Gdk.CursorType.WATCH)
 
     def __init__(self, window, status, uimanager, viewmanager=None):
 
@@ -408,18 +418,45 @@ class DisplayState(Callback):
         self.disprel_defpers = None
         self.disprel_active = None
         self.set_relationship_class()
+        self.export = False
+        self.backup_timer = None
 
         formatter = logging.Formatter('%(levelname)s %(name)s: %(message)s')
         warnbtn = status.get_warning_button()
-        self.rhandler = WarnHandler(capacity=400, button=warnbtn)
+        self.rhandler = WarnHandler(capacity=400, button=warnbtn, parent=window)
         self.rhandler.setFormatter(formatter)
         self.rhandler.setLevel(logging.WARNING)
         self.log = logging.getLogger()
         self.log.addHandler(self.rhandler)
-        # This call has been moved one level up, 
+        # This call has been moved one level up,
         # but this connection is still made!
         # self.dbstate.connect('database-changed', self.db_changed)
 
+    def set_backup_timer(self):
+        """
+        Set the backup timer.
+        """
+        interval = config.get('database.autobackup')
+        if self.backup_timer is not None:
+            GLib.source_remove(self.backup_timer)
+            self.backup_timer = None
+        if interval == 1:
+            minutes = 15
+        elif interval == 2:
+            minutes = 30
+        elif interval == 3:
+            minutes = 60
+        if interval > 0:
+            self.backup_timer = GLib.timeout_add_seconds(
+                minutes*60, self.__emit_autobackup)
+
+    def __emit_autobackup(self):
+        """
+        Emit an 'autobackup' signal.
+        """
+        self.emit('autobackup')
+        return True
+
     def screen_width(self):
         """
         Return the width of the current screen.
@@ -473,7 +510,7 @@ class DisplayState(Callback):
 
     def set_sensitive(self, state):
         self.window.set_sensitive(state)
-        
+
     def db_changed(self, db):
         db.connect('long-op-start', self.progress_monitor.add_op)
         self.clear_history()
@@ -486,12 +523,12 @@ class DisplayState(Callback):
 
     def set_gendepth(self, value):
         """ Set the generations we search back for showing relationships
-            on GRAMPS interface. Value must be integer > 0
+            on Gramps interface. Value must be integer > 0
             This method will be used by the preference editor when user changes
-            the generations. 
+            the generations.
         """
         self.relationship.set_depth(value)
-        
+
     def display_relationship(self, dbstate, active_handle):
         """ Construct the relationship in order to show it in the statusbar
             This can be a time intensive calculation, so we only want to do
@@ -527,21 +564,32 @@ class DisplayState(Callback):
         else:
             return ""
 
+    def set_export_mode(self, value):
+        self.set_busy_cursor(value)
+        if value == self.export:
+            return
+        else:
+            self.export = value
+
+    def get_export_mode(self):
+        return self.export
+
     def set_busy_cursor(self, value):
         if value == self.busy:
             return
         else:
             self.busy = value
-        if value:
-            self.cursor = self.window.get_window().get_cursor()
-            self.window.get_window().set_cursor(self.BUSY_CURSOR)
-        else:
-            self.window.get_window().set_cursor(self.cursor)
-        if self.window.get_window().is_visible():
-            #avoid critical gdk error: 
-            #Gdk-CRITICAL **: gdk_error_trap_pop_internal: assertion `trap != NULL' failed
-            #only process events if window is actually visible
-            process_pending_events()
+        if self.window.get_window():
+            if value:
+                self.cursor = self.window.get_window().get_cursor()
+                self.window.get_window().set_cursor(self.BUSY_CURSOR)
+            else:
+                self.window.get_window().set_cursor(self.cursor)
+                if self.window.get_window().is_visible():
+                    #avoid critical gdk error:
+                    #Gdk-CRITICAL **: gdk_error_trap_pop_internal: assertion `trap != NULL' failed
+                    #only process events if window is actually visible
+                    process_pending_events()
 
     def set_open_widget(self, widget):
         self.widget = widget
@@ -555,7 +603,7 @@ class DisplayState(Callback):
 
     def show_filter_results(self, dbstate, matched, total):
         #nav_type = self.viewmanager.active_page.navigation_type()
-        #text = ((_("%(nav_type)s View") % {"nav_type": _(nav_type)}) + 
+        #text = ((_("%(nav_type)s View") % {"nav_type": _(nav_type)}) +
         text = (self.viewmanager.active_page.get_title() +
                 (": %d/%d" % (matched, total)))
         self.status.set_filter(text)
@@ -565,15 +613,18 @@ class DisplayState(Callback):
 
     def modify_statusbar(self, dbstate, active=None):
         view = self.viewmanager.active_page
-        if not isinstance(view, NavigationView):
+        if not isinstance(view, NavigationView) or dbstate is None:
             return
 
         nav_type = view.navigation_type()
         active_handle = self.get_active(nav_type, view.navigation_group())
-        
+
         self.status.pop(self.status_id)
 
-        name, obj = navigation_label(dbstate.db, nav_type, active_handle)
+        if active_handle:
+            name, obj = navigation_label(dbstate.db, nav_type, active_handle)
+        else:
+            name = _('No active object')
 
         # Append relationship to default person if funtionality is enabled.
         if nav_type == 'Person' and active_handle \
