@@ -53,10 +53,11 @@ class EditPlaceRef(EditReference):
                                update)
 
     def _local_init(self):
-        self.width_key = 'interface.place-ref-width'
-        self.height_key = 'interface.place-ref-height'
+
         self.top = Glade()
         self.set_window(self.top.toplevel, None, _('Place Reference Editor'))
+        self.setup_configs('interface.place-ref', 600, 450)
+
         self.define_warn_box(self.top.get_object("warning"))
         self.define_expander(self.top.get_object("expander"))
         #self.place_name_label = self.top.get_object('place_name_label')
@@ -66,13 +67,13 @@ class EditPlaceRef(EditReference):
         notebook = self.top.get_object('notebook_ref')
         #recreate start page as GrampsTab
         notebook.remove_page(0)
-        self.reftab = RefTab(self.dbstate, self.uistate, self.track, 
+        self.reftab = RefTab(self.dbstate, self.uistate, self.track,
                               _('General'), tblref)
         tblref =  self.top.get_object('table62')
         notebook = self.top.get_object('notebook')
         #recreate start page as GrampsTab
         notebook.remove_page(0)
-        self.primtab = RefTab(self.dbstate, self.uistate, self.track, 
+        self.primtab = RefTab(self.dbstate, self.uistate, self.track,
                               _('_General'), tblref)
 
     def _connect_signals(self):
@@ -83,7 +84,7 @@ class EditPlaceRef(EditReference):
 
     def _connect_db_signals(self):
         """
-        Connect any signals that need to be connected. 
+        Connect any signals that need to be connected.
         Called by the init routine of the base class (_EditPrimary).
         """
         self._add_db_signal('place-rebuild', self.close)
@@ -102,7 +103,7 @@ class EditPlaceRef(EditReference):
         self.date_field = MonitoredDate(self.top.get_object("date_entry"),
                                         self.top.get_object("date_stat"),
                                         self.source_ref.get_date_object(),
-                                        self.uistate, self.track, 
+                                        self.uistate, self.track,
                                         self.db.readonly)
 
         if not config.get('preferences.place-auto'):
@@ -112,36 +113,38 @@ class EditPlaceRef(EditReference):
                                         self.source.set_title,
                                         self.source.get_title,
                                         self.db.readonly)
-        
+
         self.name = MonitoredEntry(self.top.get_object("name_entry"),
                                     self.source.get_name().set_value,
                                     self.source.get_name().get_value,
                                     self.db.readonly,
                                     changed=self.name_changed)
-        
+
         edit_button = self.top.get_object("name_button")
         edit_button.connect('clicked', self.edit_place_name)
 
         self.gid = MonitoredEntry(self.top.get_object("gid"),
-                                  self.source.set_gramps_id, 
+                                  self.source.set_gramps_id,
                                   self.source.get_gramps_id, self.db.readonly)
-        
-        self.tags = MonitoredTagList(self.top.get_object("tag_label"), 
-                                     self.top.get_object("tag_button"), 
-                                     self.source.set_tag_list, 
+
+        self.tags = MonitoredTagList(self.top.get_object("tag_label"),
+                                     self.top.get_object("tag_button"),
+                                     self.source.set_tag_list,
                                      self.source.get_tag_list,
                                      self.db,
                                      self.uistate, self.track,
                                      self.db.readonly)
 
-        self.privacy = PrivacyButton(self.top.get_object("private"), self.source, 
+        self.privacy = PrivacyButton(self.top.get_object("private"), self.source,
                                      self.db.readonly)
 
+        custom_place_types = sorted(self.db.get_place_types(),
+                                    key=lambda s: s.lower())
         self.place_type = MonitoredDataType(self.top.get_object("place_type"),
                                             self.source.set_type,
                                             self.source.get_type,
                                             self.db.readonly,
-                                            self.db.get_place_types())
+                                            custom_place_types)
 
         self.code = MonitoredEntry(
             self.top.get_object("code_entry"),
@@ -164,13 +167,37 @@ class EditPlaceRef(EditReference):
         #force validation now with initial entry
         self.top.get_object("lat_entry").validate(force=True)
 
+        self.latlon = MonitoredEntry(
+            self.top.get_object("latlon_entry"),
+            self.set_latlongitude, self.get_latlongitude,
+            self.db.readonly)
+
+    def set_latlongitude(self, value):
+        try:
+            coma = value.index(',')
+            self.longitude.set_text(value[coma+1:])
+            self.latitude.set_text(value[:coma])
+            self.top.get_object("lat_entry").validate(force=True)
+            self.top.get_object("lon_entry").validate(force=True)
+            self.obj.set_latitude(self.latitude.get_value())
+            self.obj.set_longitude(self.longitude.get_value())
+        except:
+            pass
+
+    def get_latlongitude(self):
+        return ""
+
     def _validate_coordinate(self, widget, text, typedeg):
         if (typedeg == 'lat') and not conv_lat_lon(text, "0", "ISO-D"):
-            return ValidationError(_("Invalid latitude (syntax: 18\u00b09'") +
-                                   _('48.21"S, -18.2412 or -18:9:48.21)'))
+            return ValidationError(
+                # translators: translate the "S" too (and the "or" of course)
+                _('Invalid latitude\n(syntax: '
+                  '18\u00b09\'48.21"S, -18.2412 or -18:9:48.21)'))
         elif (typedeg == 'lon') and not conv_lat_lon("0", text, "ISO-D"):
-            return ValidationError(_("Invalid longitude (syntax: 18\u00b09'") +
-                                   _('48.21"E, -18.2412 or -18:9:48.21)'))
+            return ValidationError(
+                # translators: translate the "E" too (and the "or" of course)
+                _('Invalid longitude\n(syntax: '
+                  '18\u00b09\'48.21"E, -18.2412 or -18:9:48.21)'))
 
     def update_title(self):
         new_title = place_displayer.display(self.db, self.source)
@@ -183,7 +210,7 @@ class EditPlaceRef(EditReference):
         """
         Create the notebook tabs and inserts them into the main
         window.
-        
+
         """
         notebook = self.top.get_object('notebook')
         notebook_ref = self.top.get_object('notebook_ref')
@@ -201,7 +228,7 @@ class EditPlaceRef(EditReference):
                                                self.update_title)
         self._add_tab(notebook, self.placeref_list)
         self.track_ref_for_deletion("placeref_list")
-        
+
         self.alt_name_list = PlaceNameEmbedList(self.dbstate,
                                                 self.uistate,
                                                 self.track,
@@ -216,14 +243,14 @@ class EditPlaceRef(EditReference):
                                               self.source.alt_loc)
             self._add_tab(notebook, self.loc_list)
             self.track_ref_for_deletion("loc_list")
-        
+
         self.citation_list = CitationEmbedList(self.dbstate,
                                                self.uistate,
                                                self.track,
                                                self.source.get_citation_list())
         self._add_tab(notebook, self.citation_list)
         self.track_ref_for_deletion("citation_list")
-        
+
         self.note_tab = NoteTab(self.dbstate,
                                 self.uistate,
                                 self.track,
@@ -231,14 +258,14 @@ class EditPlaceRef(EditReference):
                                 notetype=NoteType.PLACE)
         self._add_tab(notebook, self.note_tab)
         self.track_ref_for_deletion("note_tab")
-        
+
         self.gallery_tab = GalleryTab(self.dbstate,
                                       self.uistate,
                                       self.track,
                                       self.source.get_media_list())
         self._add_tab(notebook, self.gallery_tab)
         self.track_ref_for_deletion("gallery_tab")
-       
+
         self.web_list = WebEmbedList(self.dbstate,
                                      self.uistate,
                                      self.track,
@@ -287,7 +314,7 @@ class EditPlaceRef(EditReference):
             with DbTxn(_("Add Place"), self.db) as trans:
                 self.db.add_place(self.source, trans)
             self.source_ref.ref = self.source.handle
-        
+
         if self.update:
             self.update(self.source_ref, self.source)
 
