@@ -1,7 +1,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2007  Donald N. Allingham
-# Copyright (C) 2008-2009  Brian G. Matherly
+# Copyright (C) 2008-2012  Brian G. Matherly
 # Copyright (C) 2010       Jakim Friant
 # Copyright (C) 2012-2014  Paul Franklin
 #
@@ -30,24 +30,24 @@ import time
 
 #------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #------------------------------------------------------------------------
 from gramps.gen.const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.gettext
 from gramps.gen.const import URL_HOMEPAGE
-from gramps.gen.display.name import displayer as _nd 
+from gramps.gen.display.name import displayer as _nd
 from gramps.gen.errors import ReportError
 from gramps.gen.plug.docgen import (FontStyle, ParagraphStyle, GraphicsStyle,
                                     FONT_SERIF, PARA_ALIGN_CENTER,
                                     PARA_ALIGN_LEFT, PARA_ALIGN_RIGHT,
                                     IndexMark, INDEX_TYPE_TOC)
 from gramps.gen.plug.docgen.fontscale import string_trim
-from gramps.gen.plug.menu import (BooleanOption, StringOption, NumberOption, 
+from gramps.gen.plug.menu import (BooleanOption, StringOption, NumberOption,
                                   EnumeratedListOption, FilterOption,
                                   PersonOption)
 from gramps.gen.plug.report import Report
-from gramps.gen.plug.report import utils as ReportUtils
+from gramps.gen.plug.report import utils
 from gramps.gen.plug.report import MenuReportOptions
 from gramps.gen.plug.report import stdoptions
 from gramps.gen.utils.alive import probably_alive
@@ -64,8 +64,8 @@ from gramps.plugins.lib.libholiday import g2iso
 # Constants
 #
 #------------------------------------------------------------------------
-pt2cm = ReportUtils.pt2cm
-cm2pt = ReportUtils.cm2pt
+pt2cm = utils.pt2cm
+cm2pt = utils.cm2pt
 
 # _T_ is a gramps-defined keyword -- see po/update_po.py and po/genpot.sh
 def _T_(value): # enable deferred translations (see Python docs 22.1.3.4)
@@ -93,7 +93,7 @@ class Calendar(Report):
         stdoptions.run_private_data_option(self, menu)
 
         get_value = lambda name: menu.get_option_by_name(name).get_value()
-        
+
         self.year = get_value('year')
         self.name_format = get_value('name_format')
         self.country = get_value('country')
@@ -107,16 +107,17 @@ class Calendar(Report):
         self.text3 = get_value('text3')
         self.filter_option = menu.get_option_by_name('filter')
         self.filter = self.filter_option.get_filter()
+
         pid = get_value('pid')
         self.center_person = self.database.get_person_from_gramps_id(pid)
-        if (self.center_person == None) :
-            raise ReportError(_("Person %s is not in the Database") % pid )
+        if self.center_person is None:
+            raise ReportError(_("Person %s is not in the Database") % pid)
 
-        self._locale = self.set_locale(get_value('trans'))
+        self.set_locale(get_value('trans'))
 
     def get_name(self, person, maiden_name = None):
-        """ Return person's name, unless maiden_name given, 
-            unless married_name listed. 
+        """ Return person's name, unless maiden_name given,
+            unless married_name listed.
         """
         # Get all of a person's names:
         primary_name = person.get_primary_name()
@@ -139,7 +140,7 @@ class Calendar(Report):
             name = Name(primary_name)
         name.set_display_as(self.name_format)
         return _nd.display_name(name)
-        
+
     def draw_rectangle(self, style, sx, sy, ex, ey):
         """ This should be in BaseDoc """
         self.doc.draw_line(style, sx, sy, sx, ey)
@@ -164,7 +165,7 @@ class Calendar(Report):
         holiday_table.load_holidays(self.year, country)
         for month in range(1, 13):
             for day in range(1, 32):
-                holiday_names = holiday_table.get_holidays(month, day) 
+                holiday_names = holiday_table.get_holidays(month, day)
                 for holiday_name in holiday_names:
                     self.add_day_item(self._(holiday_name), month, day,
                                       "CAL-Holiday")
@@ -187,15 +188,15 @@ class Calendar(Report):
         """
         # initialize the dict to fill:
         self.calendar = {}
-        
+
         # get the information, first from holidays:
         if self.country != 0:
             self.__get_holidays()
-            
+
         # get data from database:
         self.collect_data()
         # generate the report:
-        with self._user.progress(_('Calendar Report'), 
+        with self._user.progress(_('Calendar Report'),
                                  _('Formatting months...'),
                                  12) as step:
             for month in range(1, 13):
@@ -226,7 +227,7 @@ class Calendar(Report):
         self.doc.draw_box("CAL-Title", "", 0, 0, width, header, mark)
         self.doc.draw_line("CAL-Border", 0, header, width, header)
         year = self.year
-        # TRANSLATORS: see 
+        # TRANSLATORS: see
         # http://gramps-project.org/wiki/index.php?title=Translating_Gramps#Translating_dates
         # to learn how to select proper inflection for your language.
         title = self._("{long_month} {year}").format(
@@ -250,10 +251,10 @@ class Calendar(Report):
             current_ord = current_date.toordinal()
         for day_col in range(7):
             font_height = pt2cm(pdaynames.get_font().get_size())
-            self.doc.center_text("CAL-Daynames", 
+            self.doc.center_text("CAL-Daynames",
                                  long_days[(day_col+ g2iso(self.start_dow + 1))
-                                                        % 7 + 1].capitalize(), 
-                                 day_col * cell_width + cell_width/2, 
+                                                        % 7 + 1].capitalize(),
+                                 day_col * cell_width + cell_width/2,
                                  header - font_height * 1.5)
         for week_row in range(6):
             something_this_week = 0
@@ -261,16 +262,16 @@ class Calendar(Report):
                 thisday = current_date.fromordinal(current_ord)
                 if thisday.month == month:
                     something_this_week = 1
-                    self.draw_rectangle("CAL-Border", day_col * cell_width, 
-                                        header + week_row * cell_height, 
-                                        (day_col + 1) * cell_width, 
+                    self.draw_rectangle("CAL-Border", day_col * cell_width,
+                                        header + week_row * cell_height,
+                                        (day_col + 1) * cell_width,
                                         header + (week_row + 1) * cell_height)
                     last_edge = (day_col + 1) * cell_width
-                    self.doc.center_text("CAL-Numbers", str(thisday.day), 
-                                         day_col * cell_width + cell_width/2, 
+                    self.doc.center_text("CAL-Numbers", str(thisday.day),
+                                         day_col * cell_width + cell_width/2,
                                          header + week_row * cell_height)
                     list_ = self.calendar.get(month, {}).get(thisday.day, [])
-                    list_.sort(key= lambda a: a[0], reverse=True) # to get CAL-Holiday on bottom
+                    list_.sort() # to get CAL-Holiday on bottom
                     position = spacing
                     for (format, p, m_list) in list_:
                         for line in reversed(p.split("\n")):
@@ -279,8 +280,8 @@ class Calendar(Report):
                                 break
                             font = ptext.get_font()
                             line = string_trim(font, line, cm2pt(cell_width + 0.2))
-                            self.doc.draw_text(format, line, 
-                                               day_col * cell_width + 0.1, 
+                            self.doc.draw_text(format, line,
+                                               day_col * cell_width + 0.1,
                                                header + (week_row + 1) * cell_height - position - 0.1, m_list[0])
                             if len(m_list) > 1: # index the spouse too
                                 self.doc.draw_text(format, "",0,0, m_list[1])
@@ -294,14 +295,14 @@ class Calendar(Report):
         if text1 == _(_TITLE1):
             text1 = self._(_TITLE1)
         self.doc.center_text("CAL-Text1style", text1,
-                             x, height - font_height * 3) 
+                             x, height - font_height * 3)
         text2 = str(self.text2)
         if text2 == _(_TITLE2):
             text2 = self._(_TITLE2)
         self.doc.center_text("CAL-Text2style", text2,
-                             x, height - font_height * 2) 
+                             x, height - font_height * 2)
         self.doc.center_text("CAL-Text3style", self.text3,
-                             x, height - font_height * 1) 
+                             x, height - font_height * 1)
         self.doc.end_page()
 
     def collect_data(self):
@@ -311,20 +312,17 @@ class Calendar(Report):
         """
         db = self.database
         people = db.iter_person_handles()
-        with self._user.progress(_('Calendar Report'), 
-                                 _('Applying Filter...'), 
-                                 db.get_number_of_people()) as step:
-            people = self.filter.apply(self.database, people, step)
+        people = self.filter.apply(self.database, people, user=self._user)
 
         ngettext = self._locale.translation.ngettext # to see "nearby" comments
 
-        with self._user.progress(_('Calendar Report'), 
+        with self._user.progress(_('Calendar Report'),
                                  _('Reading database...'),
                                  len(people)) as step:
             for person_handle in people:
                 step()
                 person = db.get_person_from_handle(person_handle)
-                mark = ReportUtils.get_person_mark(db, person)
+                mark = utils.get_person_mark(db, person)
                 birth_ref = person.get_birth_ref()
                 birth_date = None
                 if birth_ref:
@@ -375,7 +373,7 @@ class Calendar(Report):
                         self.add_day_item(text, month, day, marks=[mark])
                 if self.anniversaries:
                     family_list = person.get_family_handle_list()
-                    for fhandle in family_list: 
+                    for fhandle in family_list:
                         fam = db.get_family_from_handle(fhandle)
                         father_handle = fam.get_father_handle()
                         mother_handle = fam.get_mother_handle()
@@ -387,25 +385,25 @@ class Calendar(Report):
                         if spouse_handle:
                             spouse = db.get_person_from_handle(spouse_handle)
                             if spouse:
-                                s_m = ReportUtils.get_person_mark(db, spouse)
+                                s_m = utils.get_person_mark(db, spouse)
                                 spouse_name = self.get_name(spouse)
                                 short_name = self.get_name(person)
                                 # TEMP: this will handle ordered events
-                                # GRAMPS 3.0 will have a new mechanism for start/stop events
+                                # Gramps 3.0 will have a new mechanism for start/stop events
                                 are_married = None
                                 for event_ref in fam.get_event_ref_list():
                                     event = db.get_event_from_handle(event_ref.ref)
                                     et = EventType
                                     rt = EventRoleType
-                                    if event.type in [et.MARRIAGE, 
+                                    if event.type in [et.MARRIAGE,
                                                       et.MARR_ALT] and \
-                                        (event_ref.get_role() == rt.FAMILY or 
+                                        (event_ref.get_role() == rt.FAMILY or
                                          event_ref.get_role() == rt.PRIMARY ):
                                         are_married = event
-                                    elif event.type in [et.DIVORCE, 
-                                                        et.ANNULMENT, 
+                                    elif event.type in [et.DIVORCE,
+                                                        et.ANNULMENT,
                                                         et.DIV_FILING] and \
-                                        (event_ref.get_role() == rt.FAMILY or 
+                                        (event_ref.get_role() == rt.FAMILY or
                                          event_ref.get_role() == rt.PRIMARY ):
                                         are_married = None
                                 if are_married is not None:
@@ -421,7 +419,7 @@ class Calendar(Report):
                                             day = event_obj.get_day()
 
                                             prob_alive_date = Date(self.year, month, day)
-        
+
                                             nyears = self.year - year
                                             if nyears == 0:
                                                 text = self._('%(spouse)s and\n %(person)s, wedding') % {
@@ -430,7 +428,7 @@ class Calendar(Report):
                                                         }
                                             else:
                                                 # translators: leave all/any {...} untranslated
-                                                text = ngettext("{spouse} and\n {person}, {nyears}", 
+                                                text = ngettext("{spouse} and\n {person}, {nyears}",
                                                                 "{spouse} and\n {person}, {nyears}",
                                                                 nyears).format(spouse=spouse_name, person=short_name, nyears=nyears)
 
@@ -456,7 +454,11 @@ class CalendarOptions(MenuReportOptions):
         self.__pid = None
         self.__filter = None
         MenuReportOptions.__init__(self, name, dbase)
-    
+
+    def get_subject(self):
+        """ Return a string that describes the subject of the report. """
+        return self.__filter.get_filter().get_name()
+
     def add_menu_options(self, menu):
         """ Add the options for the graphical calendar """
 
@@ -470,12 +472,29 @@ class CalendarOptions(MenuReportOptions):
                _("Select filter to restrict people that appear on calendar"))
         add_option("filter", self.__filter)
         self.__filter.connect('value-changed', self.__filter_changed)
-        
+
         self.__pid = PersonOption(_("Center Person"))
         self.__pid.set_help(_("The center person for the report"))
         menu.add_option(category_name, "pid", self.__pid)
         self.__pid.connect('value-changed', self.__update_filters)
 
+        text1 = StringOption(_("Text Area 1"), _(_TITLE1))
+        text1.set_help(_("First line of text at bottom of calendar"))
+        add_option("text1", text1)
+
+        text2 = StringOption(_("Text Area 2"), _(_TITLE2))
+        text2.set_help(_("Second line of text at bottom of calendar"))
+        add_option("text2", text2)
+
+        text3 = StringOption(_("Text Area 3"), URL_HOMEPAGE)
+        text3.set_help(_("Third line of text at bottom of calendar"))
+        add_option("text3", text3)
+
+        ##########################
+        category_name = _("Report Options (2)")
+        add_option = partial(menu.add_option, category_name)
+        ##########################
+
         self._nf = stdoptions.add_name_format_option(menu, category_name)
         self._nf.connect('value-changed', self.__update_filters)
 
@@ -490,11 +509,11 @@ class CalendarOptions(MenuReportOptions):
         stdoptions.add_localization_option(menu, category_name)
 
         ##########################
-        category_name = _("Content Options")
+        category_name = _("Content")
         add_option = partial(menu.add_option, category_name)
         ##########################
 
-        year = NumberOption(_("Year of calendar"), time.localtime()[0], 
+        year = NumberOption(_("Year of calendar"), time.localtime()[0],
                             1000, 3000)
         year.set_help(_("Year of calendar"))
         add_option("year", year)
@@ -503,7 +522,7 @@ class CalendarOptions(MenuReportOptions):
         holiday_table = libholiday.HolidayTable()
         countries = holiday_table.get_countries()
         countries.sort()
-        if (len(countries) == 0 or 
+        if (len(countries) == 0 or
             (len(countries) > 0 and countries[0] != '')):
             countries.insert(0, '')
         count = 0
@@ -516,43 +535,33 @@ class CalendarOptions(MenuReportOptions):
         start_dow = EnumeratedListOption(_("First day of week"), 1)
         long_days = date_displayer.long_days
         for count in range(1, 8):
-            # conversion between gramps numbering (sun=1) and iso numbering (mon=1) of weekdays below
-            start_dow.add_item((count+5) % 7 + 1, long_days[count].capitalize()) 
-        start_dow.set_help(_("Select the first day of the week for the calendar"))
-        add_option("start_dow", start_dow) 
+            # conversion between gramps numbering (sun=1)
+            # and iso numbering (mon=1) of weekdays below
+            start_dow.add_item((count + 5) % 7 + 1,
+                               long_days[count].capitalize())
+        start_dow.set_help(
+            _("Select the first day of the week for the calendar"))
+        add_option("start_dow", start_dow)
 
         maiden_name = EnumeratedListOption(_("Birthday surname"), "own")
-        maiden_name.add_item("spouse_first", _("Wives use husband's surname (from first family listed)"))
-        maiden_name.add_item("spouse_last", _("Wives use husband's surname (from last family listed)"))
+        maiden_name.add_item(
+            "spouse_first",
+            _("Wives use husband's surname (from first family listed)"))
+        maiden_name.add_item(
+            "spouse_last",
+            _("Wives use husband's surname (from last family listed)"))
         maiden_name.add_item("own", _("Wives use their own surname"))
         maiden_name.set_help(_("Select married women's displayed surname"))
         add_option("maiden_name", maiden_name)
 
         birthdays = BooleanOption(_("Include birthdays"), True)
-        birthdays.set_help(_("Include birthdays in the calendar"))
+        birthdays.set_help(_("Whether to include birthdays"))
         add_option("birthdays", birthdays)
 
         anniversaries = BooleanOption(_("Include anniversaries"), True)
-        anniversaries.set_help(_("Include anniversaries in the calendar"))
+        anniversaries.set_help(_("Whether to include anniversaries"))
         add_option("anniversaries", anniversaries)
 
-        ##########################
-        category_name = _("Text Options")
-        add_option = partial(menu.add_option, _("Text Options"))
-        ##########################
-
-        text1 = StringOption(_("Text Area 1"), _(_TITLE1)) 
-        text1.set_help(_("First line of text at bottom of calendar"))
-        add_option("text1", text1)
-
-        text2 = StringOption(_("Text Area 2"), _(_TITLE2))
-        text2.set_help(_("Second line of text at bottom of calendar"))
-        add_option("text2", text2)
-
-        text3 = StringOption(_("Text Area 3"), URL_HOMEPAGE)
-        text3.set_help(_("Third line of text at bottom of calendar"))
-        add_option("text3", text3)
-        
     def __update_filters(self):
         """
         Update the filter list based on the selected person
@@ -560,9 +569,9 @@ class CalendarOptions(MenuReportOptions):
         gid = self.__pid.get_value()
         person = self.__db.get_person_from_gramps_id(gid)
         nfv = self._nf.get_value()
-        filter_list = ReportUtils.get_person_filters(person,
-                                                     include_single=False,
-                                                     name_format=nfv)
+        filter_list = utils.get_person_filters(person,
+                                               include_single=False,
+                                               name_format=nfv)
         self.__filter.set_filters(filter_list)
 
     def __filter_changed(self):
@@ -571,16 +580,15 @@ class CalendarOptions(MenuReportOptions):
         disable the person option
         """
         filter_value = self.__filter.get_value()
-        if filter_value in [1, 2, 3, 4]:
-            # Filters 1, 2, 3 and 4 rely on the center person
-            self.__pid.set_available(True)
-        else:
-            # The rest don't
+        if filter_value == 0: # "Entire Database" (as "include_single=False")
             self.__pid.set_available(False)
+        else:
+            # The other filters need a center person (assume custom ones too)
+            self.__pid.set_available(True)
 
-    def make_my_style(self, default_style, name, description, 
-                      size=9, font=FONT_SERIF, justified ="left", 
-                      color=None, align=PARA_ALIGN_CENTER, 
+    def make_my_style(self, default_style, name, description,
+                      size=9, font=FONT_SERIF, justified ="left",
+                      color=None, align=PARA_ALIGN_CENTER,
                       shadow = None, italic=0, bold=0, borders=0, indent=None):
         """ Create paragraph and graphic styles of the same name """
         # Paragraph:
@@ -600,11 +608,11 @@ class CalendarOptions(MenuReportOptions):
         if indent:
             p.set(first_indent=indent)
         if justified == "left":
-            p.set_alignment(PARA_ALIGN_LEFT)       
+            p.set_alignment(PARA_ALIGN_LEFT)
         elif justified == "right":
-            p.set_alignment(PARA_ALIGN_RIGHT)       
+            p.set_alignment(PARA_ALIGN_RIGHT)
         elif justified == "center":
-            p.set_alignment(PARA_ALIGN_CENTER)       
+            p.set_alignment(PARA_ALIGN_CENTER)
         default_style.add_paragraph_style(name, p)
         # Graphics:
         g = GraphicsStyle()
@@ -616,30 +624,30 @@ class CalendarOptions(MenuReportOptions):
         if not borders:
             g.set_line_width(0)
         default_style.add_draw_style(name, g)
-        
+
     def make_default_style(self, default_style):
         """ Add the styles used in this report """
-        self.make_my_style(default_style, "CAL-Title", 
-                           _('Title text and background color'), 20, 
-                           bold=1, italic=1, 
+        self.make_my_style(default_style, "CAL-Title",
+                           _('Title text and background color'), 20,
+                           bold=1, italic=1,
                            color=(0xEA, 0xEA, 0xEA))
-        self.make_my_style(default_style, "CAL-Numbers", 
-                           _('Calendar day numbers'), 13, 
+        self.make_my_style(default_style, "CAL-Numbers",
+                           _('Calendar day numbers'), 13,
                            bold=1)
-        self.make_my_style(default_style, "CAL-Text", 
+        self.make_my_style(default_style, "CAL-Text",
                            _('Daily text display'), 9)
-        self.make_my_style(default_style, "CAL-Holiday", 
+        self.make_my_style(default_style, "CAL-Holiday",
                            _('Holiday text display'), 9,
                            bold=1, italic=1)
-        self.make_my_style(default_style, "CAL-Daynames", 
-                           _('Days of the week text'), 12, 
-                           italic=1, bold=1, 
+        self.make_my_style(default_style, "CAL-Daynames",
+                           _('Days of the week text'), 12,
+                           italic=1, bold=1,
                            color = (0xEA, 0xEA, 0xEA))
-        self.make_my_style(default_style, "CAL-Text1style", 
+        self.make_my_style(default_style, "CAL-Text1style",
                            _('Text at bottom, line 1'), 12)
-        self.make_my_style(default_style, "CAL-Text2style", 
+        self.make_my_style(default_style, "CAL-Text2style",
                            _('Text at bottom, line 2'), 12)
-        self.make_my_style(default_style, "CAL-Text3style", 
+        self.make_my_style(default_style, "CAL-Text3style",
                            _('Text at bottom, line 3'), 9)
-        self.make_my_style(default_style, "CAL-Border", 
+        self.make_my_style(default_style, "CAL-Border",
                            _('Borders'), borders=True)
