@@ -48,11 +48,11 @@ from gramps.gui.plug import tool
 from gramps.gui.dialog import OkDialog
 from gramps.gui.managedwindow import ManagedWindow
 from gramps.gui.display import display_help
+from gramps.gui.glade import Glade
 from gramps.gen.lib import NameOriginType, Surname
 from gramps.gen.db import DbTxn
 from gramps.gen.const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.sgettext
-from gramps.gui.glade import Glade
 
 #-------------------------------------------------------------------------
 #
@@ -74,8 +74,7 @@ PREFIX_LIST = [
     "de", "van", "von", "di", "le", "du", "dela", "della",
     "des", "vande", "ten", "da", "af", "den", "das", "dello",
     "del", "en", "ein", "el" "et", "les", "lo", "los", "un",
-    "um", "una", "uno", "der", "ter", "te", "die",
-    ]
+    "um", "una", "uno", "der", "ter", "te", "die"]
 
 CONNECTOR_LIST = ['e', 'y', ]
 CONNECTOR_LIST_NONSPLIT = ['de', 'van']
@@ -100,7 +99,7 @@ class PatchNames(tool.BatchTool, ManagedWindow):
     nickid  = 2
     pref1id = 3
     compid  = 4
-    
+
     def __init__(self, dbstate, user, options_class, name, callback=None):
         uistate = user.uistate
         self.label = _('Name and title extraction tool')
@@ -109,13 +108,14 @@ class PatchNames(tool.BatchTool, ManagedWindow):
 
         tool.BatchTool.__init__(self, dbstate, user, options_class, name)
         if self.fail:
+            self.close()
             return
-        
-        winprefix = Gtk.Dialog(_("Default prefix and connector settings"),
-                                self.uistate.window,
-                                Gtk.DialogFlags.MODAL|Gtk.DialogFlags.DESTROY_WITH_PARENT,
-                                (_('_OK'), Gtk.ResponseType.ACCEPT))
-        
+
+        winprefix = Gtk.Dialog(
+            title=_("Default prefix and connector settings"),
+            transient_for=self.uistate.window, modal=True,
+            destroy_with_parent=True)
+        winprefix.add_button(_('_OK'), Gtk.ResponseType.ACCEPT)
         winprefix.vbox.set_spacing(5)
         hboxpref = Gtk.Box()
         label = Gtk.Label(label=_('Prefixes to search for:'))
@@ -138,8 +138,8 @@ class PatchNames(tool.BatchTool, ManagedWindow):
         self.connsbox.set_text(', '.join(CONNECTOR_LIST_NONSPLIT))
         hboxconns.pack_start(self.connsbox, True, True, 0)
         winprefix.vbox.pack_start(hboxconns, True, True, 0)
-        winprefix.show_all()
         winprefix.resize(700, 100)
+        winprefix.show_all()
 
         response = winprefix.run()
         self.prefix_list = self.prefixbox.get_text().split(',')
@@ -149,26 +149,29 @@ class PatchNames(tool.BatchTool, ManagedWindow):
         self.connector_list = list(map(strip, self.connector_list))
         self.conbox = None
         self.connector_list_nonsplit = self.connsbox.get_text().split(',')
-        self.connector_list_nonsplit = list(map(strip, self.connector_list_nonsplit))
+        self.connector_list_nonsplit = list(
+            map(strip, self.connector_list_nonsplit))
         self.connsbox = None
-        
+
         # Find a prefix in the first_name
-        self._fn_prefix_re = re.compile("(\S+)\s+(%s)\s*$" % '|'.join(self.prefix_list),
-                           re.IGNORECASE)
+        self._fn_prefix_re = re.compile(
+            r"(\S+)\s+(%s)\s*$" % '|'.join(self.prefix_list), re.IGNORECASE)
 
         # Find a prefix in the surname
-        self._sn_prefix_re = re.compile("^\s*(%s)\s+(.+)" % '|'.join(self.prefix_list),
-                           re.IGNORECASE)
+        self._sn_prefix_re = re.compile(
+            r"^\s*(%s)\s+(.+)" % '|'.join(self.prefix_list), re.IGNORECASE)
         # Find a connector in the surname
-        self._sn_con_re = re.compile("^\s*(.+)\s+(%s)\s+(.+)" % '|'.join(self.connector_list),
-                           re.IGNORECASE)
+        self._sn_con_re = re.compile(
+            r"^\s*(.+)\s+(%s)\s+(.+)" % '|'.join(self.connector_list),
+            re.IGNORECASE)
         winprefix.destroy()
 
         self.cb = callback
         self.handle_to_action = {}
 
         self.progress = ProgressMeter(
-            _('Extracting Information from Names'), '')
+            _('Extracting Information from Names'), '',
+            parent=self.uistate.window)
         self.progress.set_pass(_('Analyzing names'),
                                self.db.get_number_of_people())
 
@@ -177,7 +180,7 @@ class PatchNames(tool.BatchTool, ManagedWindow):
             name = person.get_primary_name()
             first = name.get_first_name()
             sname = name.get_surname()
-            
+
             old_prefix = []
             old_surn = []
             old_con = []
@@ -205,7 +208,7 @@ class PatchNames(tool.BatchTool, ManagedWindow):
             matchnick = _nick_re.match(first)
 
             if new_title:
-                titleval = (" ".join(old_title+new_title), first)
+                titleval = (" ".join(old_title + new_title), first)
                 if key in self.handle_to_action:
                     self.handle_to_action[key][self.titleid] = titleval
                 else:
@@ -249,15 +252,15 @@ class PatchNames(tool.BatchTool, ManagedWindow):
                     for ind in range(len(prefixes)):
                         origs.append(NameOriginType())
                     origs[0] = old_orig[0]
-                    compoundval = (surnames, prefixes, ['']*len(prefixes),
-                                    primaries, origs)
+                    compoundval = (surnames, prefixes, [''] * len(prefixes),
+                                   primaries, origs)
                     if key in self.handle_to_action:
                         self.handle_to_action[key][self.compid] = compoundval
                     else:
                         self.handle_to_action[key] = {self.compid: compoundval}
                     #we cannot check compound surnames, so continue the loop
                     continue
-                    
+
             # Next, try to split surname in compounds: prefix surname connector
             found = False
             new_prefix_list = []
@@ -267,8 +270,8 @@ class PatchNames(tool.BatchTool, ManagedWindow):
             new_orig_list = []
             ind = 0
             cont = True
-            for pref, surn, con, prim, orig in zip(old_prefix, old_surn, 
-                                        old_con, old_prim, old_orig):
+            for pref, surn, con, prim, orig in zip(
+                    old_prefix, old_surn, old_con, old_prim, old_orig):
                 surnval = surn.split()
                 if surnval == []:
                     new_prefix_list.append(pref)
@@ -285,7 +288,7 @@ class PatchNames(tool.BatchTool, ManagedWindow):
                     new_connector_list.append(con)
                     new_prim_list.append(prim)
                     new_orig_list.append(orig)
-                    
+
                     while cont and (val.lower() in self.prefix_list):
                         found = True
                         if new_prefix_list[-1]:
@@ -306,7 +309,8 @@ class PatchNames(tool.BatchTool, ManagedWindow):
                             val = ''
                             cont = False
                     #if value after surname indicates continue, then continue
-                    while cont and (val.lower() in self.connector_list_nonsplit):
+                    while cont and (
+                            val.lower() in self.connector_list_nonsplit):
                         #add this val to the current surname
                         new_surname_list[-1] += ' ' + val
                         try:
@@ -314,10 +318,10 @@ class PatchNames(tool.BatchTool, ManagedWindow):
                         except IndexError:
                             val = ''
                             cont = False
-                    # if previous is non-splitting connector, then add new val to
-                    # current surname
+                    # if previous is non-splitting connector, then add new val
+                    # to current surname
                     if cont and (new_surname_list[-1].split()[-1].lower()
-                                    in self.connector_list_nonsplit):
+                                 in self.connector_list_nonsplit):
                         new_surname_list[-1] += ' ' + val
                         try:
                             val = surnval.pop(0)
@@ -336,18 +340,19 @@ class PatchNames(tool.BatchTool, ManagedWindow):
                         except IndexError:
                             val = ''
                             cont = False
-                    #initialize for a next surname in case there are still 
-                    #val
+                    # initialize for a next surname in case there are still
+                    # val
                     if cont:
                         found = True  # we split surname
-                        pref=''
+                        pref = ''
                         con = ''
                         prim = False
                         orig = NameOriginType()
                 ind += 1
             if found:
-                compoundval = (new_surname_list, new_prefix_list, 
-                            new_connector_list, new_prim_list, new_orig_list)
+                compoundval = (new_surname_list, new_prefix_list,
+                               new_connector_list, new_prim_list,
+                               new_orig_list)
                 if key in self.handle_to_action:
                     self.handle_to_action[key][self.compid] = compoundval
                 else:
@@ -361,7 +366,8 @@ class PatchNames(tool.BatchTool, ManagedWindow):
             self.progress.close()
             self.close()
             OkDialog(_('No modifications made'),
-                     _("No titles, nicknames or prefixes were found"))
+                     _("No titles, nicknames or prefixes were found"),
+                     parent=self.uistate.window)
 
     def build_menu_names(self, obj):
         return (self.label, None)
@@ -377,14 +383,14 @@ class PatchNames(tool.BatchTool, ManagedWindow):
         self.top = Glade()
         window = self.top.toplevel
         self.top.connect_signals({
-            "destroy_passed_object" : self.close,
-            "on_ok_clicked" : self.on_ok_clicked,
-            "on_help_clicked" : self.on_help_clicked,
-            "on_delete_event"   : self.close,
-            })
+            "destroy_passed_object": self.close,
+            "on_ok_clicked": self.on_ok_clicked,
+            "on_help_clicked": self.on_help_clicked,
+            "on_delete_event": self.close})
 
         self.list = self.top.get_object("list")
         self.set_window(window, self.top.get_object('title'), self.label)
+        self.setup_configs("interface.patchnames", 680, 400)
 
         self.model = Gtk.ListStore(GObject.TYPE_BOOLEAN, GObject.TYPE_STRING,
                                    GObject.TYPE_STRING, GObject.TYPE_STRING,
@@ -404,7 +410,8 @@ class PatchNames(tool.BatchTool, ManagedWindow):
         c = Gtk.TreeViewColumn(_('Value'), Gtk.CellRendererText(), text=3)
         self.list.append_column(c)
 
-        c = Gtk.TreeViewColumn(_('Current Name'), Gtk.CellRendererText(), text=4)
+        c = Gtk.TreeViewColumn(_('Current Name'), Gtk.CellRendererText(),
+                               text=4)
         self.list.append_column(c)
 
         self.list.set_model(self.model)
@@ -427,9 +434,10 @@ class PatchNames(tool.BatchTool, ManagedWindow):
                 self.model.set_value(handle, 1, gid)
                 self.model.set_value(handle, 2, _('Nickname'))
                 self.model.set_value(handle, 3, nick)
-                self.model.set_value(handle, 4, p.get_primary_name().get_name())
+                self.model.set_value(handle, 4,
+                                     p.get_primary_name().get_name())
                 self.nick_hash[key] = handle
-                
+
             if self.titleid in data:
                 title, given = data[self.titleid]
                 handle = self.model.append()
@@ -437,9 +445,10 @@ class PatchNames(tool.BatchTool, ManagedWindow):
                 self.model.set_value(handle, 1, gid)
                 self.model.set_value(handle, 2, _('Person|Title'))
                 self.model.set_value(handle, 3, title)
-                self.model.set_value(handle, 4, p.get_primary_name().get_name())
+                self.model.set_value(
+                    handle, 4, p.get_primary_name().get_name())
                 self.title_hash[key] = handle
-            
+
             if self.pref1id in data:
                 given, prefixtotal, new_prefix = data[self.pref1id]
                 handle = self.model.append()
@@ -447,11 +456,13 @@ class PatchNames(tool.BatchTool, ManagedWindow):
                 self.model.set_value(handle, 1, gid)
                 self.model.set_value(handle, 2, _('Prefix in given name'))
                 self.model.set_value(handle, 3, prefixtotal)
-                self.model.set_value(handle, 4, p.get_primary_name().get_name())
+                self.model.set_value(
+                    handle, 4, p.get_primary_name().get_name())
                 self.prefix1_hash[key] = handle
-            
+
             if self.compid in data:
-                surn_list, pref_list, con_list, prims, origs = data[self.compid]
+                surn_list, pref_list, con_list, prims, origs =\
+                    data[self.compid]
                 handle = self.model.append()
                 self.model.set_value(handle, 0, 1)
                 self.model.set_value(handle, 1, gid)
@@ -461,23 +472,24 @@ class PatchNames(tool.BatchTool, ManagedWindow):
                     if newval:
                         newval += '-['
                     else:
-                        newval =  '['
+                        newval = '['
                     newval += pre + ',' + sur
                     if con:
                         newval += ',' + con + ']'
                     else:
                         newval += ']'
                 self.model.set_value(handle, 3, newval)
-                self.model.set_value(handle, 4, p.get_primary_name().get_name())
+                self.model.set_value(handle, 4,
+                                     p.get_primary_name().get_name())
                 self.compound_hash[key] = handle
-                
+
             self.progress.step()
 
         self.progress.close()
         self.show()
 
     def on_help_clicked(self, obj):
-        """Display the relevant portion of GRAMPS manual"""
+        """Display the relevant portion of Gramps manual"""
         display_help(webpage=WIKI_HELP_PAGE, section=WIKI_HELP_SEC)
 
     def on_ok_clicked(self, obj):
@@ -495,7 +507,7 @@ class PatchNames(tool.BatchTool, ManagedWindow):
                         name = p.get_primary_name()
                         name.set_first_name(given.strip())
                         name.set_nick_name(nick.strip())
-                
+
                 if self.titleid in data:
                     modelhandle = self.title_hash[key]
                     val = self.model.get_value(modelhandle, 0)
@@ -504,7 +516,7 @@ class PatchNames(tool.BatchTool, ManagedWindow):
                         name = p.get_primary_name()
                         name.set_first_name(given.strip())
                         name.set_title(title.strip())
-                
+
                 if self.pref1id in data:
                     modelhandle = self.prefix1_hash[key]
                     val = self.model.get_value(modelhandle, 0)
@@ -516,8 +528,9 @@ class PatchNames(tool.BatchTool, ManagedWindow):
                         if oldpref == '' or oldpref == prefix.strip():
                             name.get_surname_list()[0].set_prefix(prefix)
                         else:
-                            name.get_surname_list()[0].set_prefix('%s %s' % (prefix, oldpref))
-                
+                            name.get_surname_list()[0].set_prefix(
+                                '%s %s' % (prefix, oldpref))
+
                 if self.compid in data:
                     modelhandle = self.compound_hash[key]
                     val = self.model.get_value(modelhandle, 0)
@@ -525,8 +538,8 @@ class PatchNames(tool.BatchTool, ManagedWindow):
                         surns, prefs, cons, prims, origs = data[self.compid]
                         name = p.get_primary_name()
                         new_surn_list = []
-                        for surn, pref, con, prim, orig in zip(surns, prefs, cons,
-                                                                prims, origs):
+                        for surn, pref, con, prim, orig in zip(
+                                surns, prefs, cons, prims, origs):
                             new_surn_list.append(Surname())
                             new_surn_list[-1].set_surname(surn.strip())
                             new_surn_list[-1].set_prefix(pref.strip())
@@ -534,14 +547,15 @@ class PatchNames(tool.BatchTool, ManagedWindow):
                             new_surn_list[-1].set_primary(prim)
                             new_surn_list[-1].set_origintype(orig)
                         name.set_surname_list(new_surn_list)
-                    
+
                 self.db.commit_person(p, trans)
-    
+
         self.db.enable_signals()
         self.db.request_rebuild()
         self.close()
         self.cb()
 
+
 class PatchNamesOptions(tool.ToolOptions):
     """
     Defines options and provides handling interface.
@@ -550,6 +564,6 @@ class PatchNamesOptions(tool.ToolOptions):
     def __init__(self, name, person_id=None):
         tool.ToolOptions.__init__(self, name, person_id)
 
+
 def strip(arg):
     return arg.strip()
-
