@@ -17,7 +17,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 """Tools/Database Processing/Rebuild Secondary Indexes"""
@@ -27,8 +27,6 @@
 # python modules
 #
 #-------------------------------------------------------------------------
-from __future__ import print_function
-
 from gramps.gen.const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.gettext
 
@@ -48,7 +46,7 @@ log = logging.getLogger(".Rebuild")
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
 from gramps.gui.plug import tool
@@ -64,25 +62,25 @@ class Rebuild(tool.Tool, UpdateCallback):
 
     def __init__(self, dbstate, user, options_class, name, callback=None):
         uistate = user.uistate
-        
+
         tool.Tool.__init__(self, dbstate, options_class, name)
 
         if self.db.readonly:
             return
 
         self.db.disable_signals()
-        
+
         if uistate:
             self.callback = uistate.pulse_progressbar
             uistate.set_busy_cursor(True)
             uistate.progress.show()
             uistate.push_message(dbstate, _("Rebuilding secondary indexes..."))
-            
+
             UpdateCallback.__init__(self, self.callback)
             self.set_total(12)
             self.db.rebuild_secondary(self.update)
             self.reset()
-            
+
             uistate.set_busy_cursor(False)
             uistate.progress.hide()
             OkDialog(_("Secondary indexes rebuilt"),
@@ -97,7 +95,7 @@ class Rebuild(tool.Tool, UpdateCallback):
 
 #------------------------------------------------------------------------
 #
-# 
+#
 #
 #------------------------------------------------------------------------
 class RebuildOptions(tool.ToolOptions):
