@@ -2,7 +2,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2011 Serge Noiraud
+# Copyright (C) 2011-2016 Serge Noiraud
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,9 +25,15 @@
 #
 #------------------------------------------------------------------------
 
-MODULE_VERSION="4.2" 
+# pylint: disable=bad-whitespace
+# pylint: disable=bad-whitespace
+
+MODULE_VERSION = "5.0"
 
 from gi import Repository
+from gramps.gen.const import GRAMPS_LOCALE as glocale
+from gramps.gen.plug._pluginreg import register, VIEW, STABLE #, END, START
+_ = glocale.translation.gettext
 
 #-------------------------------------------------------------------------
 #
@@ -40,20 +46,14 @@ _LOG = logging.getLogger("Geography")
 # Attempting to import OsmGpsMap gives an error dialog if OsmGpsMap is not
 # available so test first and log just a warning to the console instead.
 OSMGPSMAP = False
-repository = Repository.get_default()
-if repository.enumerate_versions("OsmGpsMap"):
-    try :
+REPOSITORY = Repository.get_default()
+if REPOSITORY.enumerate_versions("OsmGpsMap"):
+    try:
         # current osmgpsmap support GTK3
         import gi
         gi.require_version('OsmGpsMap', '1.0')
         from gi.repository import OsmGpsMap as osmgpsmap
-        if osmgpsmap._version < '0.8':
-            _LOG.warning( _("OsmGpsMap module not loaded. "
-                               "OsmGpsMap must be >= 0.8. yours is %s") %
-                            osmgpsmap._version)
-        else:
-            OSMGPSMAP = True
-            _LOG.info("OsmGpsMap loaded, version : " +  osmgpsmap._version)
+        OSMGPSMAP = True
     except:
         pass
 
@@ -64,22 +64,28 @@ if not OSMGPSMAP:
         if has_display():
             from gramps.gui.dialog import MessageHideDialog
             from gramps.gen.const import URL_WIKISTRING
-            osmgps_dict = { 'gramps_wiki_build_osmgps_url' :
-                                URL_WIKISTRING + 
+            OSMGPS_DICT = {'gramps_wiki_build_osmgps_url' :
+                                URL_WIKISTRING +
                                     "GEPS_029:_GTK3-GObject_introspection"
-                                    "_Conversion#OsmGpsMap_for_Geography" }
-            title = _("OsmGpsMap module not loaded.")
-            message = _("Geography functionality will not be available.\n"
+                                    "_Conversion#OsmGpsMap_for_Geography"}
+            TITLE = _("OsmGpsMap module not loaded.")
+            MESSAGE = _("Geography functionality will not be available.\n"
                        "To build it for Gramps see "
-                       "%(gramps_wiki_build_osmgps_url)s") % osmgps_dict
-            MessageHideDialog(title, message, 'interface.ignore-osmgpsmap')
+                       "%(gramps_wiki_build_osmgps_url)s") % OSMGPS_DICT
+            if uistate:
+                MessageHideDialog(TITLE, MESSAGE,
+                                  'interface.ignore-osmgpsmap',
+                                  parent=uistate.window)
+            else:
+                MessageHideDialog(TITLE, MESSAGE,
+                                  'interface.ignore-osmgpsmap')
 else:
     # Load the view only if osmgpsmap library is present.
-    register(VIEW, 
-             id    = 'geo1',
-             name  = _("All known places for one Person"),
-             description =  _("A view showing the places visited by "
-                              "one person during his life."),
+    register(VIEW,
+             id = 'geo1',
+             name = _("All known places for one Person"),
+             description = _("A view showing the places visited by "
+                             "one person during his life."),
              version = '1.0',
              gramps_target_version = MODULE_VERSION,
              status = STABLE,
@@ -91,12 +97,12 @@ else:
              #order = START,
              stock_icon = 'geo-show-person',
       )
-    
-    register(VIEW, 
-             id    = 'geo2',
-             name  = _("All known places for one Family"),
-             description =  _("A view showing the places visited by "
-                              "one family during all their life."),
+
+    register(VIEW,
+             id = 'geo2',
+             name = _("All known places for one Family"),
+             description = _("A view showing the places visited by "
+                             "one family during all their life."),
              version = '1.0',
              gramps_target_version = MODULE_VERSION,
              status = STABLE,
@@ -108,14 +114,16 @@ else:
              #order = START,
              stock_icon = 'geo-show-family',
       )
-    
-    register(VIEW, 
-             id    = 'geo3',
-             name  = _("Every residence or move for a person and any descendants"),
-             description =  _("A view showing all the places visited by "
-                              "all persons during their life."
-                              "\nThis is for a person and any descendant."
-                              "\nYou can see the dates corresponding to the period."),
+
+    register(VIEW,
+             id = 'geo3',
+             name = _("Every residence or move for a person "
+                      "and any descendants"),
+             description = _("A view showing all the places visited by "
+                             "all persons during their life."
+                             "\nThis is for a person and any descendant."
+                             "\nYou can see the dates corresponding to "
+                             "the period."),
              version = '1.0',
              gramps_target_version = MODULE_VERSION,
              status = STABLE,
@@ -128,12 +136,12 @@ else:
              stock_icon = 'geo-show-family',
       )
 
-    register(VIEW, 
-             id    = 'geo4',
-             name  = _("Have these two families been able to meet?"),
-             description =  _("A view showing the places visited by "
-                              "all family's members during their life: "
-                              "have these two people been able to meet?"),
+    register(VIEW,
+             id = 'geo4',
+             name = _("Have these two families been able to meet?"),
+             description = _("A view showing the places visited by "
+                             "all family's members during their life: "
+                             "have these two people been able to meet?"),
              version = '1.0.1',
              gramps_target_version = MODULE_VERSION,
              status = STABLE,
@@ -145,13 +153,13 @@ else:
              #order = START,
              stock_icon = 'geo-show-family',
       )
-    
-    register(VIEW, 
-             id    = 'geo5',
-             name  = _("Have they been able to meet?"),
-             description =  _("A view showing the places visited by "
-                              "two persons during their life: "
-                              "have these two people been able to meet?"),
+
+    register(VIEW,
+             id = 'geo5',
+             name = _("Have they been able to meet?"),
+             description = _("A view showing the places visited by "
+                             "two persons during their life: "
+                             "have these two people been able to meet?"),
              version = '1.0.1',
              gramps_target_version = MODULE_VERSION,
              status = STABLE,
@@ -163,11 +171,11 @@ else:
              #order = START,
              stock_icon = 'gramps-relation',
       )
-    
-    register(VIEW, 
-             id    = 'geo6',
-             name  = _("All known Places"),
-             description =  _("A view showing all places of the database."),
+
+    register(VIEW,
+             id = 'geo6',
+             name = _("All known Places"),
+             description = _("A view showing all places of the database."),
              version = '1.0',
              gramps_target_version = MODULE_VERSION,
              status = STABLE,
@@ -179,12 +187,12 @@ else:
              #order = START,
              stock_icon = 'geo-show-place',
       )
-    
-    register(VIEW, 
-             id    = 'geo7',
-             name  = _("All places related to Events"),
-             description =  _("A view showing all the event "
-                              "places of the database."),
+
+    register(VIEW,
+             id = 'geo7',
+             name = _("All places related to Events"),
+             description = _("A view showing all the event "
+                             "places of the database."),
              version = '1.0',
              gramps_target_version = MODULE_VERSION,
              status = STABLE,
@@ -196,4 +204,4 @@ else:
              #order = START,
              stock_icon = 'geo-show-event',
       )
-    
+
